Crate typr

Crate typr 

TypR

A typed superset of R with static type checking and transpilation to R.

This crate re-exports everything from typr-cli which provides the CLI interface, REPL, and LSP server.

For core types and compilation API, see typr-core.

Modules

cli
Command-line interface for TypR
engine
Build engine utilities for TypR CLI
fs_provider
FileSystem-based implementations of typr-core traits
io
I/O utilities for TypR CLI
lsp
LSP server for TypR.
lsp_parser
Token resolution and Markdown-highlighted type display for LSP hover.
metaprogramming
Metaprogramming utilities for TypR CLI
project
Project management utilities for TypR CLI
repl
Interactive REPL for TypR
standard_library
Standard library utilities for TypR CLI
typr_core
TypR Core

Structs

CompileOutput
Full compilation output
Compiler
Main compiler interface for TypR
FileSystemOutputHandler
Filesystem-based output handler for native compilation.
FileSystemSourceProvider
Filesystem-based source provider for native compilation.
InMemoryOutputHandler
In-memory output handler for WASM and testing
InMemorySourceProvider
In-memory source provider for WASM and testing
NativePackageChecker
Native R package checker that can query R for package availability.
StubPackageChecker
Stub package checker that does nothing (for WASM)
TranspileResult
Result of transpilation

Enums

CompileError
Compilation errors

Traits

OutputHandler
Handles output from transpilation.
PackageChecker
Checks and optionally installs R packages.
SourceProvider
Provides source code content for compilation.

Functions

start
Main entry point for the CLI