TypR
A typed superset of R with static type checking and transpilation to R.
This crate re-exports everything from typr-cli which provides
the CLI interface, REPL, and LSP server.
For core types and compilation API, see typr-core.
Modules
- cli
- Command-line interface for TypR
- engine
- Build engine utilities for TypR CLI
- fs_
provider - FileSystem-based implementations of typr-core traits
- io
- I/O utilities for TypR CLI
- lsp
- LSP server for TypR.
- lsp_
parser - Token resolution and Markdown-highlighted type display for LSP hover.
- metaprogramming
- Metaprogramming utilities for TypR CLI
- project
- Project management utilities for TypR CLI
- repl
- Interactive REPL for TypR
- standard_
library - Standard library utilities for TypR CLI
- typr_
core - TypR Core
Structs
- Compile
Output - Full compilation output
- Compiler
- Main compiler interface for TypR
- File
System Output Handler - Filesystem-based output handler for native compilation.
- File
System Source Provider - Filesystem-based source provider for native compilation.
- InMemory
Output Handler - In-memory output handler for WASM and testing
- InMemory
Source Provider - In-memory source provider for WASM and testing
- Native
Package Checker - Native R package checker that can query R for package availability.
- Stub
Package Checker - Stub package checker that does nothing (for WASM)
- Transpile
Result - Result of transpilation
Enums
- Compile
Error - Compilation errors
Traits
- Output
Handler - Handles output from transpilation.
- Package
Checker - Checks and optionally installs R packages.
- Source
Provider - Provides source code content for compilation.
Functions
- start
- Main entry point for the CLI